@@ -3,10 +3,9 @@ import logging
 
 from django.db.models import get_model, ObjectDoesNotExist
 from django.contrib.admin.widgets import AdminFileWidget, ForeignKeyRawIdWidget
-from django.conf import settings
-
 from easy_thumbnails.files import get_thumbnailer
 from easy_thumbnails.source_generators import pil_image
+from .config import settings
 
 logger = logging.getLogger(__name__)
 
@@ -15,10 +14,11 @@ def thumbnail(image_path):
     thumbnailer = get_thumbnailer(image_path)
     thumbnail_options = {
         'detail': True,
-        'size': getattr(settings, 'IMAGE_CROPPING_THUMB_SIZE', (300, 300)),
+        'upscale': True,
+        'size': settings.IMAGE_CROPPING_THUMB_SIZE,
     }
     thumb = thumbnailer.get_thumbnail(thumbnail_options)
-    return thumb.url
+    return thumb
 
 
 def get_attrs(image, name):
@@ -39,10 +39,9 @@ def get_attrs(image, name):
             # invalid image -> AttributeError
             width = image.width
             height = image.height
-
         return {
             'class': "crop-thumb",
-            'data-thumbnail-url': thumbnail(image),
+            'data-thumbnail-url': thumbnail(image).url,
             'data-field-name': name,
             'data-org-width': width,
             'data-org-height': height,
@@ -55,12 +54,12 @@ def get_attrs(image, name):
 class CropWidget(object):
     class Media:
         js = (
-            getattr(settings, 'JQUERY_URL',
-                    'https://ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js'),
+            settings.IMAGE_CROPPING_JQUERY_URL,
             "image_cropping/js/jquery.Jcrop.min.js",
             "image_cropping/image_cropping.js",
         )
-        css = {'all': ("image_cropping/css/jquery.Jcrop.min.css",)}
+        css = {'all': ("image_cropping/css/jquery.Jcrop.min.css",
+                       "image_cropping/css/image_cropping.css",)}
 
 
 class ImageCropWidget(AdminFileWidget, CropWidget):
